==> open-cluster-management-cluster-model-6.8.1-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1beta1/ManagedClusterSetBindingSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ManagedClusterSetBindingSpecFluent<A extends ManagedClusterSetBindingSpecFluent<A>> extends BaseFluent<A>{
  public ManagedClusterSetBindingSpecFluent() {
  }
  public ManagedClusterSetBindingSpecFluent(ManagedClusterSetBindingSpec instance) {
    instance = (instance != null ? instance : new ManagedClusterSetBindingSpec());

    if (instance != null) {
      this.withClusterSet(instance.getClusterSet());
      this.withClusterSet(instance.getClusterSet());
    }
  }
  private String clusterSet;
  public String getClusterSet() {
    return this.clusterSet;
  }
  public A withClusterSet(String clusterSet) {
    this.clusterSet=clusterSet; return (A) this;
  }
  public boolean hasClusterSet() {
    return this.clusterSet != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ManagedClusterSetBindingSpecFluent that = (ManagedClusterSetBindingSpecFluent) o;
    if (!java.util.Objects.equals(clusterSet, that.clusterSet)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clusterSet,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterSet != null) { sb.append("clusterSet:"); sb.append(clusterSet); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-cluster-model-6.9.0-sources.jar: io/fabric8/openclustermanagement/api/model/cluster/v1beta1/ManagedClusterSetBindingSpecFluent.java <==
package io.fabric8.openclustermanagement.api.model.cluster.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ManagedClusterSetBindingSpecFluent<A extends ManagedClusterSetBindingSpecFluent<A>> extends BaseFluent<A>{
  public ManagedClusterSetBindingSpecFluent() {
  }
  
  public ManagedClusterSetBindingSpecFluent(ManagedClusterSetBindingSpec instance) {
    this.copyInstance(instance);
  }
  private String clusterSet;
  
  protected void copyInstance(ManagedClusterSetBindingSpec instance) {
    instance = (instance != null ? instance : new ManagedClusterSetBindingSpec());
  
    if (instance != null) {
        this.withClusterSet(instance.getClusterSet());
        this.withClusterSet(instance.getClusterSet());
      }
  }
  
  public String getClusterSet() {
    return this.clusterSet;
  }
  
  public A withClusterSet(String clusterSet) {
    this.clusterSet=clusterSet; return (A) this;
  }
  
  public boolean hasClusterSet() {
    return this.clusterSet != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ManagedClusterSetBindingSpecFluent that = (ManagedClusterSetBindingSpecFluent) o;
    if (!java.util.Objects.equals(clusterSet, that.clusterSet)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(clusterSet,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clusterSet != null) { sb.append("clusterSet:"); sb.append(clusterSet); }
    sb.append("}");
    return sb.toString();
  }
  

}
